@@ -20,7 +20,7 @@
  * @author    Jorrit Schippers <jschippers@php.net>
  * @copyright 1997-2008 The PHP Group
  * @license   http://www.php.net/license/3_0.txt PHP License 3.0
- * @version   CVS: $Id: FTP.php,v 1.53.2.3 2008/01/08 18:35:43 jschippers Exp $
+ * @version   CVS: $Id: FTP.php,v 1.53.2.10 2008/05/19 18:01:08 jschippers Exp $
  * @link      http://pear.php.net/package/Net_FTP
  * @since     File available since Release 0.0.1
  */
@@ -482,7 +482,7 @@ define('NET_FTP_ERR_EXTFILELOAD_FAILED', -35);
  * @author    Jorrit Schippers <jschippers@php.net>
  * @copyright 1997-2008 The PHP Group
  * @license   http://www.php.net/license/3_0.txt PHP License 3.0
- * @version   Release: 1.3.5
+ * @version   Release: 1.3.7
  * @link      http://pear.php.net/package/Net_FTP
  * @since     0.0.1
  * @access    public
@@ -632,8 +632,8 @@ class Net_FTP extends PEAR
         
         $this->_ls_match = array(
             'unix'    => array(
-                'pattern' => '/(?:(d)|.)([rwxt-]+)\s+(\w+)\s+([\w\d-()?]+)\s+'.
-                             '([\w\d-()?]+)\s+(\w+)\s+(\S+\s+\S+\s+\S+)\s+(.+)/',
+                'pattern' => '/(?:(d)|.)([rwxts-]{9})\s+(\w+)\s+([\w\d-()?.]+)\s+'.
+                             '([\w\d-()?.]+)\s+(\w+)\s+(\S+\s+\S+\s+\S+)\s+(.+)/',
                 'map'     => array(
                     'is_dir'        => 1,
                     'rights'        => 2,
@@ -974,7 +974,7 @@ class Net_FTP extends PEAR
             $mode     = NET_FTP_DIRS_ONLY;
             $dir_list = $this->ls($remote_path, $mode);
             foreach ($dir_list as $dir_entry) {
-                if ($dir_entry == '.' || $dir_entry == '..') {
+                if ($dir_entry['name'] == '.' || $dir_entry['name'] == '..') {
                     continue;
                 }
                 
@@ -1430,6 +1430,9 @@ class Net_FTP extends PEAR
         }
         $dir_list = array();
         $dir_list = $this->ls($remote_path, NET_FTP_DIRS_ONLY);
+        if (PEAR::isError($dir_list)) {
+            return $dir_list;
+        }
         foreach ($dir_list as $dir_entry) {
             if ($dir_entry['name'] != '.' && $dir_entry['name'] != '..') {
                 $remote_path_new = $remote_path.$dir_entry["name"]."/";
@@ -1443,6 +1446,9 @@ class Net_FTP extends PEAR
         }
         $file_list = array();
         $file_list = $this->ls($remote_path, NET_FTP_FILES_ONLY);
+        if (PEAR::isError($file_list)) {
+            return $file_list;
+        }
         foreach ($file_list as $file_entry) {
             $remote_file = $remote_path.$file_entry["name"];
             $local_file  = $local_path.$file_entry["name"];
@@ -1488,7 +1494,7 @@ class Net_FTP extends PEAR
                           $mode = null)
     {
         $remote_path = $this->_constructPath($remote_path);
-        if (!$this->_checkDir($local_path) || !is_dir($local_path)) {
+        if (!file_exists($local_path) || !is_dir($local_path)) {
             return $this->raiseError("Given local-path '".$local_path.
                                      "' seems not to be a directory.",
                                      NET_FTP_ERR_LOCALPATHNODIR);
@@ -1508,6 +1514,7 @@ class Net_FTP extends PEAR
         $this->cd($old_path);
         $dir_list = $this->_lsLocal($local_path);
         foreach ($dir_list["dirs"] as $dir_entry) {
+            // local directories do not have arrays as entry
             $remote_path_new = $remote_path.$dir_entry."/";
             $local_path_new  = $local_path.$dir_entry."/";
             $result          = $this->putRecursive($local_path_new,
@@ -2229,7 +2236,8 @@ class Net_FTP extends PEAR
     {
         foreach ($dir_list as $entry) {
             foreach ($this->_ls_match as $os => $match) {
-                if (preg_match($match['pattern'], $entry)) {
+                $matches = array();
+                if (preg_match($match['pattern'], $entry, $matches)) {
                     return $match;
                 }
             }
