@@ -21,12 +21,12 @@
  * @author    Tobias Schlitt <toby@php.net>
  * @copyright 1997-2008 The PHP Group
  * @license   http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version   CVS: $Id: Socket.php,v 1.5.2.1 2008/01/07 14:21:22 jschippers Exp $
+ * @version   CVS: $Id: Socket.php,v 1.5.2.2 2008/04/22 19:47:08 jschippers Exp $
  * @link      http://pear.php.net/package/Net_FTP
  * @since     File available since Release 0.0.1
  */
 
-error_reporting(E_ALL|E_STRICT);
+error_reporting(E_ALL);
 
 /**
 * Default FTP extension constants
